# zema_emc_annotated

[![pipeline status](https://gitlab1.ptb.de/m4d/zema_emc_annotated/badges/main/pipeline.svg)](https://gitlab1.ptb.de/m4d/zema_emc_annotated/-/commits/main)
[![Documentation Status](https://readthedocs.org/projects/zema-emc-annotated/badge/?version=latest)](https://zema-emc-annotated.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/PTB-M4D/zema_emc_annotated/branch/main/graph/badge.svg?token=HQZE3FXL7N)](https://app.codecov.io/gh/PTB-M4D/zema_emc_annotated?search=&displayType=list&trend=7%20days)
[![Latest Release](https://img.shields.io/github/v/release/PTB-M4D/zema_emc_annotated?label=Latest%20Release)](https://github.com/PTB-M4D/zema_emc_annotated/releases/latest)
[![DOI](https://zenodo.org/badge/591514193.svg)](https://doi.org/10.5281/zenodo.7556142)

This software provides a convenient API to access the [annotated ZeMA dataset about 
remaining useful life of an electro-mechanical cylinder on
Zenodo](https://doi.org/10.5281/zenodo.5185953). The code was written for _Python 3.10_.

## Getting started

The [INSTALL guide](INSTALL.md) assists in installing the required packages. 
Afterwards please visit our
[example page](https://zema-emc-annotated.readthedocs.io/en/latest/examples.html).

## Documentation

The documentation can be found on
[ReadTheDocs](https://zema-emc-annotated.readthedocs.io/en/latest/).

## Disclaimer

This software is developed at Physikalisch-Technische Bundesanstalt (PTB). The software
is made available "as is" free of cost. PTB assumes no responsibility whatsoever for
its use by other parties, and makes no guarantees, expressed or implied, about its
quality, reliability, safety, suitability or any other characteristic. In no event
will PTB be liable for any direct, indirect or consequential damage arising in
connection with the use of this software.

## License

zema_emc_annotated is distributed under the [MIT
license](https://github.com/PTB-M4D/zema_emc_annotated/blob/main/LICENSE).
